.\" -*-troff-*-
.\" ====================================================================
.\"  @Troff-man-file{
.\"     author          = "Nelson H. F. Beebe",
.\"     version         = "0.00",
.\"     date            = "20 December 2002",
.\"     time            = "12:36:32 MST",
.\"     filename        = "man2texi.man",
.\"     address         = "Center for Scientific Computing
.\"                        University of Utah
.\"                        Department of Mathematics, 110 LCB
.\"                        155 S 1400 E RM 233
.\"                        Salt Lake City, UT 84112-0090
.\"                        USA",
.\"     telephone       = "+1 801 581 5254",
.\"     FAX             = "+1 801 581 4148",
.\"     URL             = "http://www.math.utah.edu/~beebe",
.\"     checksum        = "55239 323 1142 8627",
.\"     email           = "beebe@math.utah.edu, beebe@acm.org,
.\"                        beebe@computer.org, beebe@ieee.org (Internet)",
.\"     codetable       = "ISO/ASCII",
.\"     keywords        = "DocBook/XML; documentation; Emacs info; GNU
.\"                        system; HTML; makeinfo; nroff; SGML; TeX;
.\"                        TeXinfo; texinfo; troff; Unix manual pages;
.\"                        xinfo; XML",
.\"     supported       = "yes",
.\"     docstring       = "This file documents man2texi, a program for
.\"                        converting well-structured Unix manual page
.\"                        files in nroff/troff format to TeXinfo
.\"                        format, which can be typeset by TeX, and/or
.\"                        converted by makeinfo to Emacs info files,
.\"                        HTML, and DocBook/XML files.
.\"
.\"                        The checksum field above contains a CRC-16
.\"                        checksum as the first value, followed by the
.\"                        equivalent of the standard UNIX wc (word
.\"                        count) utility output of lines, words, and
.\"                        characters.  This is produced by Robert
.\"                        Solovay's checksum utility.",
.\"  }
.\" ====================================================================
.\"
.if t .ds Te T\\h'-0.1667m'\\v'0.20v'E\\v'-0.20v'\\h'-0.125m'X
.if n .ds Te TeX
.\"
.TH MAN2TEXI 1 "@PACKAGE_DATE@" "@PACKAGE_VERSION@"
.\" ----------------------------------------------
.SH NAME
man2texi \(em Unix manual page to TeXinfo converter
.\" ----------------------------------------------
.SH SYNOPSIS
.B man2texi
[
.B \-?
]
[
.B \-author
]
[
.B \-batch
]
[
.B \-copyright
]
.if n .ti +9n
[
.B \-dvi
]
[
.BI \-filename " filename"
]
[
.B \-help
]
[
.B \-info
]
.if n .ti +9n
.if t .ti +\w'\fBman2texi\fP\ 'u
[
.B \-version
]
[ infile(s) ] [ > outfile ]
.\" ----------------------------------------------
.SH OPTIONS
.B man2texi
options can be prefixed with either one or two
hyphens, and can be abbreviated to any unique
prefix.  Thus,
.BR \-a ,
.BR \-author ,
and
.B \-\-auth
are equivalent.
.PP
To avoid confusion with options, if a filename
begins with a hyphen, it must be disguised by a
leading absolute or relative directory path, e.g.,
.I /tmp/-foo.man
or
.IR ./-foo.man .
.\"-----------------------------------------------
.TP \w'\fB\-copyright\fP'u+3n
.B \-author
Display an author credit, and software
distribution information, on the standard error
unit,
.IR stderr ,
and then terminate with a success return code.
Sometimes an executable program is separated from
its documentation and source code; this option
provides a way to recover from that.
.\"-----------------------------------------------
.TP
.B \-batch
.B man2texi
normally writes its output on
.IR stdout ,
and expects only a single input file, or input
from
.IR stdin ,
if no input file is specified.
.IP
When
.B \-batch
is specified,
.B man2texi
processes each command-line file argument in turn,
writing its output into files with the same
basename, but extension
.IR .texi .
.IP
To prevent disasters, the output filename must be
different from the input filename, and any
existing
.I .texi
file is first renamed with extension
.I .texi.org
before creating a new one.
.B
.\"-----------------------------------------------
.TP
.B \-copyright
Display copyright information on the standard
error unit,
.IR stderr ,
and then terminate with a success return code.
.\"-----------------------------------------------
.TP
.B \-dvi
Run
.BR \*(Te\& (1)
to typeset the output
.I .texi
files to make
.I .dvi
files.
.IP
This option implies
.BR \-batch ,
and automatically selects that option.
.\"-----------------------------------------------
.TP
.BI \-filename " filename"
.BR \*(Te\&info (1)
files must contain the name of the target info
file.  When
.B man2texi
runs in a pipeline, it does not have a filename to
construct the needed name, so this option gives it
the needed name, which should be the name of the
manual page file.
.\"-----------------------------------------------
.TP
.BR \-help " or " \-?
Display a help message on
.IR stderr ,
giving a usage description, and then terminate
with a success return code.
.\"-----------------------------------------------
.TP
.B \-info
Run
.BR makeinfo (1)
to convert the output
.I .texi
files to
.I .info
files.
.IP
This option implies
.BR \-batch ,
and automatically selects that option.
.\"-----------------------------------------------
.TP
.B \-version
Display the program version number and release
date on
.IR stderr ,
and then terminate with a success return code.
.\" ----------------------------------------------
.SH DESCRIPTION
.B man2texi
converts well-structured Unix manual page
files in
.BR nroff (1)/
.BR troff (1)
format to
.BR \*(Te\&info (1)
format, which can be typeset
by
.BR \*(Te\& (1),
and/or converted by
.BR makeinfo (1)
to
.BR emacs (1)
.BR info (1)
files, HTML, and DocBook/XML files.
.PP
.BR \*(Te\&info (1)
files are particularly convenient for large
documents, since they can contain hypertext links
and tables of contents, allowing fast navigation
in a suitable document viewer.
.\" ----------------------------------------------
.SH "SEE ALSO"
.BR emacs (1),
.BR info (1),
.BR makeinfo (1),
.BR nroff (1),
.BR \*(Te\& (1),
.BR tex (1),
.BR texinfo (1),
.BR troff (1),
.BR xinfo (1).
.\" ----------------------------------------------
.SH BUGS
.B man2texi
expects its input to follow reasonably strict, but
common, conventions for UNIX manual page markup,
as documented in Sun SunOS and Solaris
.BR troff (1)
manuals.
.\" ----------------------------------------------
.SH AVAILABILITY
.B man2texi
is available from its master archive:
.RS
.nf
\&\fCftp://ftp.math.utah.edu/pub/man2texi
http://www.math.utah.edu/pub/man2texi/\fP
.fi
.RE
It requires only a few standard UNIX/POSIX tools,
and is expected to be trivially installable on
virtually any modern UNIX or POSIX-conformant
system.  It does, however, expect features of
fairly recent releases of the
.BR texinfo (1)
system, available at
.RS
.nf
\&\fCftp://ftp.gnu.org/gnu/texinfo
http://www.gnu.org/software/texinfo\fP
.fi
.RE
If the validation tests run at software
installation time by \fCmake check\fP succeed,
then the local
.BR texinfo (1)
installation is acceptably recent.
.\" ----------------------------------------------
.SH COPYRIGHT
.B man2texi
is licensed under the GNU General Public License
as published by the Free Software Foundation;
either version 2, or (at your option) any later
version.  A copy of that license is included in
the file
.I COPYING
included with the
.B man2texi
distribution.  The license is also available from
the Free Software Foundation, 675 Mass Ave,
Cambridge, MA 02139, USA, and at its World-Wide
Web site at
.RS
.nf
\&\fChttp://www.gnu.org/licenses/\fP
.fi
.RE
.\" ----------------------------------------------
.SH ACKNOWLEDGEMENTS
Donald Knuth wrote
.BR \*(Te\& (1).
.BR makeinfo (1)
and the
.BR \*(Te\&info (1)
software documentation system were developed by
the Free Software Foundation.
Thanks to all of them for improving public access
to software documentation.
.\" ----------------------------------------------
.SH AUTHOR
.nf
Nelson H. F. Beebe
Center for Scientific Computing
University of Utah
Department of Mathematics, 110 LCB
155 S 1400 E RM 233
Salt Lake City, UT 84112-0090
USA
Tel: +1 801 581 5254
FAX: +1 801 581 4148
Email: \fCbeebe@math.utah.edu\fP, \fCbeebe@acm.org\fP,
       \fCbeebe@computer.org\fP, \fCbeebe@ieee.org\fP (Internet)
URL: \fChttp://www.math.utah.edu/~beebe\fP
.fi
.\"=====================================================================
.\" This is for GNU Emacs file-specific customization:
.\" Local Variables:
.\" fill-column: 50
.\" End:
